@@ -1,7 +1,7 @@
 #! /usr/bin/perl
 
 # ex:ts=8 sw=4:
-# $OpenBSD: Quirks.pm,v 1.216 2015/02/27 12:37:04 espie Exp $
+# $OpenBSD: Quirks.pm,v 1.169 2014/07/25 09:17:16 zhuk Exp $
 #
 # Copyright (c) 2009 Marc Espie <espie@openbsd.org>
 #
@@ -96,8 +96,6 @@ my $base_exceptions = {
 	'sqlite3' => '/usr/bin/sqlite3',
 # 5.6
 	'unbound' => '/usr/sbin/unbound',
-# 5.7
-	'p5-IO-Socket-IP' => "$p5/IO/Socket/IP.pm",
 };
 
 my $stem_extensions = {
@@ -259,6 +257,7 @@ my $stem_extensions = {
 	'php5-mapscript' => 'php-mapscript',
 	'libusb' => 'libusb-compat',
 	'pecl-pcntl' => 'php-pcntl',
+	'distribute' => 'py3-distribute',
 	'aspell6-ar' => 'aspell-ar',
 	'aspell6-bg' => 'aspell-bg',
 	'aspell6-ca' => 'aspell-ca',
@@ -311,6 +310,9 @@ my $stem_extensions = {
 	'ruby19-ruby-augeas' => 'ruby19-augeas',
 	'ruby-ruby-augeas' => 'ruby-augeas',
 	'nail' => 's-nail',
+	'mariadb-client' => 'mysql-client',
+	'mariadb-server' => 'mysql-server',
+	'mariadb-tests' => 'mysql-tests',
 	'coxpcall' => 'lua-coxpcall',
 	'lpeg' => 'lua-lpeg',
 	'ruby-facter' => 'facter',
@@ -330,6 +332,7 @@ my $stem_extensions = {
 	'foomatic-filters' => 'cups-filters',
 	'faad-xmms' => 'xmms-faad',
 	'p5-MojoX-Renderer-TT' => 'p5-Mojolicious-Plugin-TtRenderer',
+
 # 5.6
 	'p5-Class-MOP' => 'p5-Moose',
 	'libproxy-mozilla' => 'libproxy-webkit',
@@ -350,16 +353,6 @@ my $stem_extensions = {
 	'kdnssd' => 'zeroconf-ioslave',
 	'kwallet' => 'kwalletmanager',
 	'p5-TAP-Parser' => 'p5-Test-Harness',
-# 5.7
-	'qlandkarte' => 'qlandkartegt',
-	'mysql-client' => 'mariadb-client',
-	'mysql-server' => 'mariadb-server',
-	'mysql-tests' => 'mariadb-tests',
-	'py3-distribute' => 'py3-setuptools',
-	'symon-mon' => 'symon',
-	'symon-mux' => 'symux',
-	'ruby-dbus' => 'ruby21-dbus',
-	'polarssl' => 'mbedtls',
 };
 
 # reasons for obsolete packages
@@ -369,7 +362,6 @@ my @msg = (
 	"no longer maintained and full of security holes", #2
 	"no longer maintained upstream", #3
 	"superseded by base component", #4
-	"outdated and/or no longer required by other ports", #5
 );
 
 my $obsolete_reason = {
@@ -431,76 +423,6 @@ my $obsolete_reason = {
 	'xmms-bonk' => 3,
 	'mailcrypt' => 0,
 	'tcpcat' => 4,
-	'ctm' => 3,
-	'papyon' => 3,
-	'bacula-web' => 1,
-	'waf' => 0,
-	'ruby-echoe' => 3,
-	'ruby-rubyforge' => 0,
-	'luastatgrab' => 3,
-	'ruby-home_run' => 3,
-	'ruby-parsetree' => 3,
-	'ruby-rdoc' => 3,
-	'ruby-rcov' => 3,
-	'ruby-fastercsv' => 3,
-	'ruby-fastri' => 3,
-	'ruby-mongrel' => 3,
-	'eruby' => 3,
-	'mod_ruby' => 3,
-	'py3-distribute' => 3,
-	'raggle' => 3,
-	'gnome-icon-theme-extras' => 3,
-	'ruby-fastthread' => 3,
-	'dellflash' => 0,
-	'libgee06' => 3,
-	'smarty' => 2,
-	'smarty-docs' => 2,
-	'wdsetup' => 0,
-	'pptp' => 0,
-	'aumix' => 0,
-	'ac3dec' => 3,
-	'flash' => 3,
-	'ruby-columnize' => 3,
-	'ruby-mini_magick' => 3,
-	'ruby-spreadsheet' => 3,
-	'ruby-minion' => 3,
-	'ruby-bunny' => 3,
-	'ruby-randexp' => 3,
-	'synaesthesia' => 0,
-	'mew' => 0,
-	'auctex' => 0,
-	'emacs-zenirc' => 3,
-	'emacs-zenirc-el' => 3,
-	'newsfetch' => 2,
-	'esound' => 3,
-	'extace' => 3,
-	'gkrellmss' => 3,
-	'mixer.app' => 0,
-	'wmix' => 0,
-	'wmmixer' => 0,
-	'xmix' => 0,
-	'xmmix' => 0,
-	'pecl-APC' => 3,
-	'fxtv' => 3,
-	'hudson' => 2,
-	'epdfview' => 0,
-	'p5-HTTP-GHTTP' => 3,
-	'libghttp' => 3,
-	'ruby-hub' => 3,
-	'erl-webmachine' => 0,
-	'commons-io' => 2,
-	'qt4-qtsolutions-singleinstance' => 3,
-	'hs-cgi' => 5,
-	'hs-HsParrot' => 5,
-	'hs-HsSyck' => 5,
-	'hs-MetaObject' => 5,
-	'hs-control-timeout' => 5,
-	'hs-pugs-DrIFT' => 5,
-	'hs-pugs-compat' => 5,
-	'hs-regex-pcre-builtin' => 5,
-	'hs-stringtable-atom' => 5,
-	'pugs' => 5,
-	'xawtv' => 5,
 };
 
 # ->is_base_system($handle, $state):
@@ -520,13 +442,12 @@ sub is_base_system
 	my $test = $base_exceptions->{$stem};
 	if (defined $test) {
 		if (-e $test) {
-			$state->say("Removing #1 #2", $handle->pkgname,
+			$state->say("Removing ", $handle->pkgname,
 			    " (part of base system now)");
 			return 1;
 		} else {
-			$state->say("Not removing #1 #2 #3 #4", $handle->pkgname,
+			$state->say("Not removing ", $handle->pkgname,
 			 ", ", $test, " not found");
-			return 0;
 		}
 	} else {
 		return 0;
@@ -541,7 +462,7 @@ sub filter_obsolete
 {
 	my ($self, $list, $state) = @_;
 	my @in = @$list;
-	$list = [];
+	@$list = ();
 	for my $pkgname (@in) {
 		my $stem = OpenBSD::PackageName::splitstem($pkgname);
 		my $reason = $obsolete_reason->{$stem};
@@ -591,10 +512,6 @@ my $cve = {
 	'mail/exim' => 'exim-<4.83',
 	'www/p5-CGI-Application' => 'p5-CGI-Application-<4.50p0',
 	'www/cherokee,-ldap' => 'cherokee-ldap-<1.2.101p6',
-	'shells/bash' => 'bash-<4.3.27',
-	'www/drupal7/core' => 'drupal->=7.0,<7.32',
-	'audio/flac' => 'flac-<1.3.0p1',
-	'www/drupal6/views' => 'drupal6-views-<2.18',
 };
 
 # ->check_security($path)
